@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -106,7 +106,7 @@ sub LoadDefaults {
 
     # ProductName
     # (Application name displayed in frontend.)
-    $Self->{ProductName} = 'Znuny LTS';
+    $Self->{ProductName} = 'Znuny';
 
     # --------------------------------------------------- #
     # database settings                                   #
@@ -716,10 +716,6 @@ sub LoadDefaults {
     # agent interface notification module to check the admin user id
     # (don't work with user id 1 notification)
     $Self->{'Frontend::NotifyModule'} = {
-        '1000-CloudServicesDisabled' => {
-            Group  => 'admin',
-            Module => 'Kernel::Output::HTML::Notification::AgentCloudServicesDisabled',
-        },
         '1100-OTRSBusiness' => {
             Group  => 'admin',
             Module => 'Kernel::Output::HTML::Notification::AgentOTRSBusiness',
@@ -913,15 +909,15 @@ sub LoadDefaults {
     # --------------------------------------------------- #
     # MIME-Viewer for online to html converter
     # --------------------------------------------------- #
-    # (e.g. xlhtml (xls2html), http://chicago.sourceforge.net/xlhtml/)
-#     $Self->{'MIME-Viewer'}->{'application/excel'} = 'xlhtml';
+    # (e. g. xlhtml (xls2html), http://chicago.sourceforge.net/xlhtml/)
+#    $Self->{'MIME-Viewer'}->{'application/excel'} = 'xlhtml';
     # MIME-Viewer for online to html converter
-    # (e.g. wv (word2html), http://wvware.sourceforge.net/)
-#     $Self->{'MIME-Viewer'}->{'application/msword'} = 'wvWare';
-    # (e.g. pdftohtml (pdf2html), http://pdftohtml.sourceforge.net/)
-#     $Self->{'MIME-Viewer'}->{'application/pdf'} = 'pdftohtml -stdout -i';
-    # (e.g. xml2html (xml2html))
-#     $Self->{'MIME-Viewer'}->{'text/xml'} = $Self->{Home}.'/scripts/tools/xml2html.pl';
+    # (e. g. wv (word2html), http://wvware.sourceforge.net/)
+#    $Self->{'MIME-Viewer'}->{'application/msword'} = 'wvWare';
+    # (e. g. pdftohtml (pdf2html), http://pdftohtml.sourceforge.net/)
+#    $Self->{'MIME-Viewer'}->{'application/pdf'} = 'pdftohtml -stdout -i';
+    # (e. g. xml2html (xml2html))
+#    $Self->{'MIME-Viewer'}->{'text/xml'} = $Self->{Home}.'/scripts/tools/xml2html.pl';
 
     # --------------------------------------------------- #
     # directories                                         #
@@ -992,10 +988,10 @@ sub LoadDefaults {
         'thirdparty/jquery-3.5.1/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.12.1/jquery-ui.js',
         'thirdparty/jquery-pubsub/pubsub.js',
         'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/nunjucks-3.0.1/nunjucks.js',
         'Core.Init.js',
         'Core.Debug.js',
         'Core.Exception.js',
@@ -1029,12 +1025,12 @@ sub LoadDefaults {
     $Self->{'Loader::Agent::CommonJS'}->{'000-Framework'} = [
         'thirdparty/jquery-3.5.1/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.12.1/jquery-ui.js',
         'thirdparty/jquery-ui-touch-punch-0.2.3/jquery.ui.touch-punch.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
         'thirdparty/jquery-pubsub/pubsub.js',
         'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
-        'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
+        'thirdparty/nunjucks-3.0.1/nunjucks.js',
         'Core.Init.js',
         'Core.JavaScriptEnhancements.js',
         'Core.Debug.js',
